@@ -13,7 +13,7 @@ Usage::
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_mediatailor.type_defs import (
     ListPlaybackConfigurationsResponseTypeDef,
@@ -31,7 +31,7 @@ class ListPlaybackConfigurationsPaginator(Boto3Paginator):
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListPlaybackConfigurationsResponseTypeDef, None, None]:
+    ) -> Iterator[ListPlaybackConfigurationsResponseTypeDef]:
         """
         [ListPlaybackConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations.paginate)
         """
